import { Router } from "express";
import {
  createCompany,
  getCompanies,
  getCompanyById,
  updateCompany,
  deleteCompany,
  assignUserCompany,
  updateUserFromCompany,
  removeUserFromACompany,
  createUserAndAssginCompany,
  createCompanyAddress,
  getCompanyAddressById,
  updateCompanyAddress,
  deleteCompanyAddress,
  createCompanyAuthorisedDetail,
  getCompanyAuthorisedDetailById,
  updateCompanyAuthorisedDetail,
  deleteCompanyAuthorisedDetail,
  getAllUserOfCompany,
  createCompanyL1User,
  getCompanyL1UserById,
  updateCompanyL1User,
  deleteCompanyL1User,
  createCompanyTradeDetail,
  getAllCompanyTradeDetails,
  getCompanyTradeDetailById,
  updateCompanyTradeDetail,
  deleteCompanyTradeDetail,
  createCompanyTradingHour,
  getAllCompanyTradingHours,
  getCompanyTradingHourById,
  updateCompanyTradingHour,
  deleteCompanyTradingHour,
  getCompanyDetaisByCompanyID,
  createCompanyKeyContact,
  getAllCompanyKeyContacts,
  getCompanyKeyContactById,
  updateCompanyKeyContact,
  deleteCompanyKeyContact,
  updateCompanyTradingHourBulk,
  createSingleCompanyTradingHour,
  getCompanyAdminUsers,
  searchCompany,
  getCompanyShowcase,
  getCompanyCount,
  updateUser,
} from "../controllers/company.controller";
import { authenticate } from "../middleware/auth.middleware";

const router = Router();

// Get front page companies
router.get("/companies/showcase", getCompanyShowcase);
router.get("/companies/count", getCompanyCount);

//only admin can create compnany
router.post("/companies/create", authenticate, createCompany); // [x] Integration complete
router.get("/companies", authenticate, getCompanies); // [x] Integration complete
router.get("/companies/search", searchCompany);
// only admin , client--admin can access
router.get("/companies/:id", authenticate, getCompanyById); // [x] Integration complete
router.put("/companies/update/:id", authenticate, updateCompany); // [x] Integration complete
router.delete("/companies/delete/:id", authenticate, deleteCompany);

// only admin , client--admin can access
router.post("/companies/my/assign-user", authenticate, assignUserCompany);
router.put(
  "/companies/my/update-user/:id",
  authenticate,
  updateUserFromCompany
);
router.delete(
  "/companies/my/remove-user/:id",
  authenticate,
  removeUserFromACompany
);

//get all user of a company
router.get("/companies/my/get-employee/:id", authenticate, getAllUserOfCompany); // [x] Integration complete

//create user and assign to company
router.post(
  "/companies/operation/create-assgin-user",
  authenticate,
  createUserAndAssginCompany
);

// Update user info
router.patch(
  "/companies/operation/update-user/:user_id",
  authenticate,
  updateUser
);

router.get("/companies/admin/:company_id", authenticate, getCompanyAdminUsers);

// Create a new company address
router.post(
  "/my-company/company-addresses",
  authenticate,
  createCompanyAddress
); // [x] Integration complete
// Get a company address by ID
router.get(
  "/my-company/company-addresses/:address_id",
  authenticate,
  getCompanyAddressById
);
// Update a company address
router.put(
  "/my-company/company-addresses/:address_id",
  authenticate,
  updateCompanyAddress
); // [x] Integration complete
// Delete a company address
router.delete(
  "/my-company/company-addresses/:address_id",
  authenticate,
  deleteCompanyAddress
);

// Create a new company authorised detail
router.post(
  "/my-company/create/company-authorised-details",
  authenticate,
  createCompanyAuthorisedDetail
); // [x] Integration complete

// Get a company authorised detail by ID
router.get(
  "/my-company/company-authorised-details/:authorised_id",
  authenticate,
  getCompanyAuthorisedDetailById
);

// Update a company authorised detail
router.put(
  "/my-company/update/company-authorised-details/:authorised_id",
  authenticate,

  updateCompanyAuthorisedDetail
); // [x] Integration complete

// Delete a company authorised detail
router.delete(
  "/my-company/company-authorised-details/:authorised_id",
  authenticate,
  deleteCompanyAuthorisedDetail
);

// Create a new company L1 user
router.post("/my-company/company-l1-users", authenticate, createCompanyL1User); // [x] Integration complete

// Get a company L1 user by ID
router.get(
  "/my-company/company-l1-users/:l1_user_id",
  authenticate,
  getCompanyL1UserById
);

// Update a company L1 user
router.put(
  "/my-company/company-l1-users/:l1_user_id",
  authenticate,
  updateCompanyL1User
); // [x] Integration complete

// Delete a company L1 user
router.delete(
  "/my-company/company-l1-users/:l1_user_id",
  authenticate,
  deleteCompanyL1User
);

// Route to create a new company trade detail
router.post(
  "/my-company/company-trade-details",
  authenticate,
  createCompanyTradeDetail
); // [x] Integration complete

// Route to get all company trade details
router.get(
  "/my-company/company-trade-details",
  authenticate,
  getAllCompanyTradeDetails
);

// Route to get a single company trade detail by ID
router.get(
  "/my-company/company-trade-details/:id",
  authenticate,
  getCompanyTradeDetailById
);

// Route to update a company trade detail by ID
router.put(
  "/my-company/company-trade-details/:id",
  authenticate,
  updateCompanyTradeDetail
); // [x] Integration complete

// Route to delete a company trade detail by ID
router.delete(
  "/my-company/company-trade-details/:id",
  authenticate,
  deleteCompanyTradeDetail
);

// Route to create a new company trading hour
router.post(
  "/my-company/single/company-trading-hours",
  authenticate,
  createSingleCompanyTradingHour
);

// Route to create many new company trading hours
router.post(
  "/my-company/company-trading-hours",
  authenticate,
  createCompanyTradingHour
); // [x] Integration complete

// Route to get all company trading hours
router.get(
  "/my-company/company-trading-hours/:cid",
  authenticate,
  getAllCompanyTradingHours
);

// Route to get a single company trading hour by ID
router.get(
  "/my-company/company-trading-hours/:id",
  authenticate,
  getCompanyTradingHourById
);

// Route to update a company trading hour by ID
router.put(
  "/my-company/company-trading-hours/:id",
  authenticate,
  updateCompanyTradingHour
);

// Route to update company trading hours by company ID
router.put(
  "/my-company/company-trading-hours",
  authenticate,
  updateCompanyTradingHourBulk
); // [x] Integration complete

// Route to delete a company trading hour by ID
router.delete(
  "/my-company/company-trading-hours/:id",
  authenticate,
  deleteCompanyTradingHour
);

// Route to create a new company key contact
router.post(
  "/my-company/company-key-contacts",
  authenticate,
  createCompanyKeyContact
); // [x] Integration complete

// Route to get all company key contacts
router.get(
  "/my-company/company-key-contacts",
  authenticate,
  getAllCompanyKeyContacts
);

// Route to get a single company key contact by ID
router.get(
  "/my-company/company-key-contacts/:key_contact_id",
  authenticate,
  getCompanyKeyContactById
);

// Route to update a company key contact by ID
router.put(
  "/my-company/company-key-contacts/:key_contact_id",
  authenticate,
  updateCompanyKeyContact
); // [x] Integration complete

// Route to delete a company key contact by ID
router.delete(
  "/my-company/company-key-contacts/:key_contact_id",
  authenticate,
  deleteCompanyKeyContact
);

router.get(
  "/my-company/details/:companyID",
  authenticate,
  getCompanyDetaisByCompanyID
); // [x] Integration complete

export default router;
